==> lein-template-0.1.6.jar: leiningen/new/web_app/src/web_app/system.clj <==
(ns {{name}}.system
    (:use
     [{{name}}.core.lifeCycle])
    (:require
     [clojure.java.io :as io]
     [clojure.tools.logging :as log]
     [{{name}}.handler :as h]
     [{{name}}.db :as db]))


(defrecord Config [file-name env]
  LifeCycle
  (start [this comp]
    (log/info (str "Loading config file..." file-name) )
    (let [app-config (-> file-name
                         (io/resource)
                         (slurp)
                         (read-string))
          default-config (:config app-config)
          config (merge default-config (get app-config env))]
      (assoc this :config config)))
  (stop [this] this))


(defonce component-order [:config :datomic :sqldb  :web])


(defrecord SystemRecord [config datomic sqldb  web]
  LifeCycle
  (start [this comp]
    (log/info "System is starting, please wait...")
    (reduce (fn [system key]
              (update-in system [key] start system))
            this
            component-order))
  (stop [this]
    (log/info "System is stoping, please wait...")
    (reduce (fn [system key]
              (update-in system [key] stop))
            this
            (reverse component-order))))


(defn system
  "Returns a new instance of the whole application. Default :prod"
  ([] (system :prod))
  ([env]
     (->SystemRecord
      (->Config "config.edn" env)
      (db/->Datomic)
      (db/->SqlDB)
      (h/->Web))))


(defonce handler nil)
(defonce the-system (atom nil))


(defn init
  "Init application, set web handler"
  ([] (init (start (system) nil)))
  ([s]
     (reset! the-system s)
     (alter-var-root #'handler (constantly (get-in @the-system [:web :handler])))
     (log/info "App start successfully")))


(defn destroy
  "Clean application resource"
  ([] (destroy true))
  ([destroy?]
     (log/info "System is going to down ")
     (if destroy?
       (do
         (log/info "Stoping service...")
         (stop @the-system)
         (reset! the-system nil)
         (alter-var-root #'handler (constantly nil))))))

==> lein-template-0.1.7.jar: leiningen/new/web_app/src/web_app/system.clj <==
(ns {{name}}.system
    (:use
     [{{name}}.core.lifeCycle])
    (:require
     [clojure.java.io :as io]
     [clojure.tools.logging :as log]
     [{{name}}.routes :as r]
     [{{name}}.db :as db]))


(defrecord Config [file-name env]
  LifeCycle
  (start [this comp]
    (log/info (str "Loading config file..." file-name) )
    (let [app-config (-> file-name
                         (io/resource)
                         (slurp)
                         (read-string))
          default-config (:config app-config)
          config (merge default-config (get app-config env))]
      (assoc this :config config)))
  (stop [this] this))


(defonce component-order [:config :datomic :sqldb  :web])


(defrecord SystemRecord [config datomic sqldb  web]
  LifeCycle
  (start [this comp]
    (log/info "System is starting, please wait...")
    (reduce (fn [system key]
              (update-in system [key] start system))
            this
            component-order))
  (stop [this]
    (log/info "System is stoping, please wait...")
    (reduce (fn [system key]
              (update-in system [key] stop))
            this
            (reverse component-order))))


(defn system
  "Returns a new instance of the whole application.
   Default env :prod in config file. "
  ([] (system :prod))
  ([env]
     (->SystemRecord
      (->Config "config.edn" env)
      (db/->Datomic)
      (db/->SqlDB)
      (r/->Web))))


(defonce handler nil)
(defonce the-system (atom nil))


(defn init
  "Init application, set web handler"
  ([] (init (start (system) nil)))
  ([s]
     (reset! the-system s)
     (alter-var-root #'handler (constantly (get-in @the-system [:web :handler])))
     (log/info "App start successfully")))


(defn destroy
  "Clean application resource"
  ([] (destroy true))
  ([destroy?]
     (log/info "System is going to down ")
     (if destroy?
       (do
         (log/info "Stoping service...")
         (stop @the-system)
         (reset! the-system nil)
         (alter-var-root #'handler (constantly nil))))))
